@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2002, 2025, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License, version 2.0, as published by
  * the Free Software Foundation.
@@ -44,7 +44,6 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Enumeration;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Locale;
@@ -52,6 +51,7 @@ import java.util.Properties;
 import java.util.Set;
 import java.util.StringJoiner;
 import java.util.concurrent.Callable;
+import java.util.stream.Collectors;
 
 import javax.net.ssl.SSLContext;
 
@@ -494,35 +494,26 @@ public abstract class BaseTestCase {
     }
 
     protected String getNoDbUrl(String url) throws SQLException {
+        return getReplacedDbUrl(url, "");
+    }
+
+    protected String getReplacedDbUrl(String url, String dbReplacement) throws SQLException {
         Properties props = getPropertiesFromUrl(ConnectionUrl.getConnectionUrlInstance(url, null));
         final String host = props.getProperty(PropertyKey.HOST.getKeyName(), "localhost");
         final String port = props.getProperty(PropertyKey.PORT.getKeyName(), "3306");
         props.remove(PropertyKey.DBNAME.getKeyName());
         removeHostRelatedProps(props);
 
-        final StringBuilder urlBuilder = new StringBuilder("jdbc:mysql://").append(host).append(":").append(port).append("/?");
-
-        Enumeration<Object> keyEnum = props.keys();
-        while (keyEnum.hasMoreElements()) {
-            String key = (String) keyEnum.nextElement();
-            urlBuilder.append(key);
-            urlBuilder.append("=");
-            urlBuilder.append(props.get(key));
-            if (keyEnum.hasMoreElements()) {
-                urlBuilder.append("&");
-            }
-        }
+        final StringBuilder urlBuilder = new StringBuilder("jdbc:mysql://").append(host).append(":").append(port).append("/").append(dbReplacement).append("?");
+        urlBuilder.append(props.stringPropertyNames().stream().map(k -> k + "=" + props.getProperty(k)).collect(Collectors.joining("&")));
         return urlBuilder.toString();
     }
 
     protected int getRowCount(String tableName) throws SQLException {
         ResultSet countRs = null;
-
         try {
             countRs = this.stmt.executeQuery("SELECT COUNT(*) FROM " + tableName);
-
             countRs.next();
-
             return countRs.getInt(1);
         } finally {
             if (countRs != null) {
@@ -833,9 +824,7 @@ public abstract class BaseTestCase {
 
     protected void cleanupTempFiles(final File exampleTempFile, final String tempfilePrefix) {
         File tempfilePath = exampleTempFile.getParentFile();
-
         File[] possibleFiles = tempfilePath.listFiles((dir, name) -> name.indexOf(tempfilePrefix) != -1 && !exampleTempFile.getName().equals(name));
-
         if (possibleFiles != null) {
             for (int i = 0; i < possibleFiles.length; i++) {
                 try {
